import { Component, OnInit } from "@angular/core";
import { Router } from "@angular/router";
import { Location } from "@angular/common";
import { Database } from "../../providers/database/database";
import { Generator } from "../../providers/generator/generator";

@Component({
    selector: "list",
    templateUrl: "./components/list/list.html",
})
export class ListComponent implements OnInit {

    public passwords: Array<any>;
    public countdown: number;
    public epochSnapshot: number;

    public constructor(private router: Router, private location: Location, private couchbase: Database, private generator: Generator) {
        this.passwords = [];
        this.epochSnapshot = 0;
    }

    public ngOnInit() {
        this.location.subscribe(path => {
            this.retrievePasswords();
        });
        this.retrievePasswords();
        this.ticker();
    }

    private ticker() {
        let epoch = Math.round(new Date().getTime() / 1000.0);
        this.countdown = (30 - (epoch % 30));
        if(epoch % 30 == 0) {
            if(epoch > this.epochSnapshot + 5) {
                this.epochSnapshot = epoch;
                this.retrievePasswords();
            }
        }
        setTimeout(() => {
            this.ticker();
        }, 100);
    }

    public create() {
        this.router.navigate(["create"]);
    }

    private retrievePasswords() {
        this.passwords = [];
        let rows = this.couchbase.getDatabase().executeQuery("passwords");
        for(let i = 0; i < rows.length; i++) {
            this.passwords.push({
                "title": rows[i].title,
                "password": this.generator.getOTP(rows[i].secret)
            });
        }
    }

}